@@ -4,7 +4,7 @@ use v5.14;
 use warnings;
 use utf8;
 
-our $VERSION = "2.1101";
+our $VERSION = "2.12";
 
 use Data::Dumper;
 $Data::Dumper::Sortkeys = 1;
@@ -37,14 +37,14 @@ my $color_re    = qr{ \e \[ [\d;]* m }x;
 my $erase_re    = qr{ \e \[ [\d;]* K }x;
 my $csi_re      = qr{
     # see ECMA-48 5.4 Control sequences
-    \e \[		# csi
+    (?: \e\[ | \x9b )	# csi
     [\x30-\x3f]*	# parameter bytes
     [\x20-\x2f]*	# intermediate bytes
     [\x40-\x7e]		# final byte
 }x;
 my $osc_re      = qr{
     # see ECMA-48 8.3.89 OSC - OPERATING SYSTEM COMMAND
-    \e \]			# osc
+    (?: \e\] | \x9d )		# osc
     [\x08-\x13\x20-\x7d]*+	# command
     (?: \e\\ | \x9c | \a )	# st: string terminator
 }x;
@@ -96,7 +96,13 @@ our $DEFAULT_LINEBREAK = LINEBREAK_NONE;
 our $DEFAULT_RUNIN_WIDTH  = 2;
 our $DEFAULT_RUNOUT_WIDTH = 2;
 
-use charnames ':full';
+BEGIN {
+    if ($] < 5.016) {
+	require charnames;
+	charnames->import(':full');
+    }
+}
+
 our %TABSTYLE = (
     pairmap {
 	( $a =~ s/_/-/gr, ref $b ? $b : [ $b, $b ] );
@@ -511,7 +517,7 @@ Text::ANSI::Fold - Text folding library supporting ANSI terminal sequence and As
 
 =head1 VERSION
 
-Version 2.1101
+Version 2.12
 
 =head1 SYNOPSIS
 
@@ -847,6 +853,11 @@ Command line utility using L<Text::ANSI::Fold>.
 
 Collection of utilities using L<Text::ANSI::Fold> module.
 
+=item L<Text::ANSI::Tabs>
+
+L<Text::Tabs> compatible tab expand/unexpand module using
+L<Text::ANSI::Fold> as a backend processor.
+
 =item L<App::sdif>
 
 L<Text::ANSI::Fold> was originally implemented in B<sdif> command for
